@@ -21,7 +21,6 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-
 #include "curl_setup.h"
 
 #include "urldata.h"
@@ -29,7 +28,6 @@
 #include "cfilters.h"
 #include "curl_trc.h"
 #include "multiif.h"
-#include "curlx/timeval.h"
 #include "multi_ev.h"
 #include "select.h"
 #include "uint-bset.h"
@@ -583,7 +581,8 @@ void Curl_multi_ev_dirty_xfers(struct Curl_multi *multi,
           Curl_multi_mark_dirty(data);
         }
         else {
-          CURL_TRC_M(multi->admin, "socket transfer %u no longer found", mid);
+          CURL_TRC_M(multi->admin,
+                     "socket transfer %u no longer found", mid);
           Curl_uint32_spbset_remove(&entry->xfers, mid);
         }
       } while(Curl_uint32_spbset_next(&entry->xfers, mid, &mid));
